mosaic <- function(formula, data = list(), cut = NULL,
  main = "", col = "lightgray", off = NULL, ...)
{
    if(inherits(formula, "formula")) {
      mf <- model.frame(formula, data = data)
      if(NCOL(mf) != 2) stop("`formula' should specify exactly two variables")
      y <- mf[,1]
      x <- mf[,2]    
      if(!is.factor(y)) stop("dependent variable should be a factor")
        
      if(!is.factor(x)) {
        if(is.null(cut)) cut <- fivenum(x)
        x <- cut(x, cut, include.lowest = TRUE)
      }

      tab <- table(x, y)
      names(dimnames(tab)) <- names(mf)[2:1]
    } else {
      if(is.table(formula) || is.array(formula)) tab <- formula
        else stop("invalid specification of `formula'")
    }
    
    if(is.null(off)) off <- (dim(tab) - 1) * 2    
    mosaicplot(tab, main = main, col = col, off = off, ...)
    invisible(tab)
}
