\name{BloodPressure}
\alias{BloodPressure}
\non_function{}
\title{Calcium and Blood Pressure}
\description{
Results of a randomized comparative experiment to investigate the effect of
calcium on blood pressure in African-American men.
}

\usage{data(BloodPressure)}
\format{A data frame with 21 observations and 4 variables.
  \describe{
    \item{Treatment}{Whether subject received calcium or placebo,}
    \item{Begin}{Seated systolic blood pressure before treatment,}
    \item{End}{Seated systolic blood pressure after treatement,}
    \item{Decrease}{Decrease in blood pressure (Begin - End).}
  }
}

\details{
Does increasing calcium intake reduce blood pressure? Observational studies
suggest that there is a link, and that it is strongest in African-American men.
Twenty-one African-American men participated in an experiment to test this
hypothesis. Ten of the men took a calcium supplement for 12 weeks while the
remaining 11 men recieved a placebo. Researchers measured the blood pressure of
each subject before and after the 12-week period. The experiment was
double-blind.

A pooled t-test is appropriate for comparing the change in blood pressure
between the treatment and placebo groups. Normal probability plots of blood
pressure change for the two groups do not show problematic departures from
normality, and the sample standard deviations do not rule out equal population
standard deviations. The pooled t-statistic is 1.634, with a p-value of .059.
}

\references{
Moore, David S., and George P. McCabe (1989). \emph{Introduction to the Practice
of Statistics}.

Lyle, Roseann M., et al. (1987), Blood pressure and metabolic effects of
calcium supplementation in normotensive white and black men, \emph{JAMA},
\bold{257}, 1772--1776.
}

\source{DASL (Data and Story Library):
\url{http://lib.stat.cmu.edu/DASL/Stories/Calcium.html}}

\examples{
data(BloodPressure)
boxplot(Decrease ~ Treatment, data = BloodPressure)
t.test(Decrease ~ Treatment, data = BloodPressure)
t.test(Decrease ~ Treatment, data = BloodPressure, var.equal = TRUE,
  alternative = "greater")
wilcox.test(Decrease ~ Treatment, data = BloodPressure, alternative =
 "greater")
}

\keyword{datasets}
