\name{BrainSize}
\alias{BrainSize}
\non_function{}
\title{Brain Size and Intelligence}
\description{
Data on brain size, intelligence and body size of 40 right-handed Anglo
introductory psychology students at a large southwestern university.
}

\usage{data(BrainSize)}
\format{A data frame with 40 observations and 7 variables.
  \describe{
    \item{Gender}{Male or Female,}
    \item{FSIQ}{Full Scale IQ scores based on the four Wechsler (1981)
 subtests,}
    \item{VIQ}{Verbal IQ scores based on the four Wechsler (1981) subtests,}
    \item{PIQ}{erformance IQ scores based on the four Wechsler (1981) subtests,}
    \item{Weight}{Body weight in pounds,}
    \item{Height}{Height in inches,}
    \item{MRI.Count}{Total pixel count from the 18 MRI scans.}
  }
}

\details{
Are the size and weight of your brain indicators of your mental capacity? In
this study by Willerman et al. (1991) the researchers use Magnetic Resonance
Imaging (MRI) to determine the brain size of the subjects. The researchers take
into account gender and body size to draw conclusions about the connection
between brain size and intelligence.

Willerman et al. (1991) conducted their study at a large southwestern
university. They selected a sample of 40 right-handed Anglo introductory
psychology students who had indicated no history of alcoholism, unconsciousness,
brain damage, epilepsy, or heart disease. These subjects were drawn from a
larger pool of introductory psychology students with total Scholastic Aptitude
Test Scores higher than 1350 or lower than 940 who had agreed to satisfy a
course requirement by allowing the administration of four subtests (Vocabulary,
Similarities, Block Design, and Picture Completion) of the Wechsler (1981) Adult
Intelligence Scale-Revised. With prior approval of the University's research
review board, students selected for MRI were required to obtain prorated
full-scale IQs of greater than 130 or less than 103, and were equally divided by
sex and IQ classification.

The MRI scans were performed at the same facility for all 40 subjects. The scans
consisted of 18 horizontal MR images. The computer counted all pixels with
non-zero gray scale in each of the 18 images and the total count served as an
index for brain size.

A straightforward method for evaluating the relationship between brain size and
IQ scores is the correllation coefficient. For the 20 men in the study, the
researchers report correlations between IQ scores and brain sizes before and
after controlling for body size of r = 0.51 (p-value less than 0.05) and r =
0.65 (p-value less than 0.01) respectively. For the 20 women in the study, the
researchers report the corresponding correlations to be r = 0.33 (p-value not
significant) and r = 0.35 (p-value not significant). With both genders pooled
the correlation between IQ and adjusted brain size was r = 0.51 (p-value less
than 0.05).
}

\references{
Willerman, L., Schultz, R., Rutledge, J. N., and Bigler, E. (1991), In Vivo
Brain Size and Intelligence, \emph{Intelligence}, \bold{15}, 223--228.
}

\source{DASL (Data and Story Library):
\url{http://lib.stat.cmu.edu/DASL/Stories/BrainSizeandIntelligence.html}}

\examples{
data(BrainSize)
plot(MRI.Count ~ Weight, col = as.numeric(Gender), pch = as.numeric(Gender),
  data = BrainSize)
}

\keyword{datasets}
