\name{CancerSurvival}
\alias{CancerSurvival}
\non_function{}
\title{Cancer Survival}
\description{Patients with advanced cancers of the stomach, bronchus, colon,
ovary or breast were treated with ascorbate. The purpose of the study was to
determine if the survival times differ with respect to the organ affected by the
cancer.}

\usage{data(CancerSurvival)}
\format{A data frame with 64 observations and 2 variables.
  \describe{
    \item{Survival}{Survival time (in days?),}
    \item{Organ}{Organ affected by the cancer.}
  }
}

\details{Patients with advanced cancers of the stomach, bronchus, colon, ovary
or breast were treated with ascorbate. The purpose of the study was to determine
if patient survival differed with respect to the organ affected by the cancer.

A one-way ANOVA with Organ as the discrete factor and Survival as the dependent
variable is appropriate for these data. A normal probability plot of the
residuals shows that they are skewed to the right. We transform the data to
alleviate this problem. A square root transformation appears to make the
residuals more symmetric, so we use the square root of Survival
\code{sqrt(Survival)} as our new dependent variable.

The ANOVA table for this analysis indicates that the means of
\code{sqrt(Survival)} are significantly different at the 5% level of
significance with a p-value of 0.0002. Figure 1 is a boxplot of
\code{sqrt(Survival)} by Organ. We can see from this plot that breast cancer
patients seem to survive much longer after receiving treatments of ascorbate
than patients with cancer of the bronchus, colon, or stomach. A post-hoc test
using Scheffe's method confirms the results of the boxplot. }

\references{
Cameron, E. and Pauling, L. (1978), Supplemental ascorbate in the supportive
treatment of cancer: re-evaluation of prolongation of survival times in terminal
human cancer. \emph{Proceedings of the National Academy of Science USA},
\bold{75}, 4538--4542.

Hand, D.J., et al. (1994), \emph{A Handbook of Small Data Sets}, London: Chapman
& Hall, 255.

Manly, B.F.J. (1986), \emph{Multivariate Statistical Methods: A Primer}, New
York: Chapman & Hall, 11.
}

\source{DASL (Data and Story Library):
\url{http://lib.stat.cmu.edu/DASL/Stories/CancerSurvival.html}}

\examples{
data(CancerSurvival)
boxplot(Survival ~ Organ, data = CancerSurvival)
boxplot(sqrt(Survival) ~ Organ, data = CancerSurvival)
}

\keyword{datasets}
