\name{FoodPoison}
\alias{FoodPoison}
\non_function{}
\title{Food Poisoning}
\description{
Data obtained in an epidemiological study following an outbreak of food
poisoning at an outing held for personnel of an insurance company.
}

\usage{data(FoodPoison)}
\format{A data frame with 8 observations and 4 variables.
  \describe{
    \item{ill}{factor indicating if person was ill or not,}
    \item{freq}{frequency of cases,}
    \item{crabmeat}{factor indicating if person ate crabmeat or not,}
    \item{potato}{factor indicating if person ate potato salad or not.}
  }
}

\details{
Questionnaires were completed by 304 of the 320 persons on the trip. Interest
focused on the potato-salad and crabmeat. The possible cause of the food
poisoning can be investigated by a log-linear Poisson model or by a logistic
regression model. It turns out that the potato salad probably caused the
illness, but still 4 persons got ill, that did not have potato salad.
}

\references{
Korff, F.A., M. A. M. Taback, and J. H. Beard (1952). \emph{Public Health
Reports}, \bold{67}, 909--913.
}

\examples{
data(FoodPoison)
food.tab <- xtabs(freq ~ ill + crabmeat + potato, data = FoodPoison)
ftable(food.tab, col.vars = "ill")
fmp <- glm(freq ~ (potato + ill + crabmeat)^3,
            data = FoodPoison, family = poisson)
fmb <- glm(ill ~ potato * crabmeat, weights = freq,
           data = FoodPoison, family = binomial)
anova(fmb, test = "F")
anova(fmp, test = "F")
loglin(food.tab, list(c(1,3), c(2,3)))
}

\keyword{datasets}
