\name{LarynxCancer}
\alias{LarynxCancer}
\non_function{}
\title{Larynx Cancer}
\description{
Results of a study by Mendenhall et al. to compare radiation therapy with
surgery in treating cancer of the larynx.
}

\usage{data(LarynxCancer)}
\format{A data frame with 41 observations and 2 variables.
  \describe{
    \item{treatment}{Type of radiation therapy (surgery, radiation therapy),}
    \item{cancer}{Whether treatment was successful (yes, no).}
  }
}

\references{
Mendenhall, W. M., R. R. Million, D. E. Sharkey, and N. J. Cassis. (1984). Stage
T3 squamous cell carcinoma of the glottic larynx treated with surgery and/or
radiation therapy. \emph{Internat. J. Radiat. Oncol. Biol. Phys.}. \bold{10},
357--363.

Agresti, A. (1990). \emph{Categorical Data Analysis}. New York: Wiley.
}

\source{DASL (Data and Story Library):
\url{http://lib.stat.cmu.edu/DASL/Datafiles/LarynxCancer.html}}

\examples{
data(LarynxCancer)
tab <- xtabs(~ treatment + cancer, data = LarynxCancer)
tab
## test homogeneity with Fisher's test, Chi-squared test
## and asymptotic test of log-odds
fisher.test(tab)
chisq.test(tab)
log.w <- log(fisher.test(tab)$estimate)
(1 - pnorm(abs(log.w - 1), sd = sum(1/tab)))*2
## radiation seems to have some advantages but there
## are far too few observations for a significant result
## (p values around 0.7)
}

\keyword{datasets}
