\name{Mustard}
\alias{Mustard}
\non_function{}
\title{Growing Mustard}
\description{
Influence of growing medium, watering and light on weight
of mustard plants.
}

\usage{data(Mustard)}
\format{A data frame with 108 observations and 4 variables.
  \describe{
    \item{weight}{weight of mustard plants (in g),}
    \item{light}{factor indicating the color of light,}
    \item{watering}{ordered factor indicating the amount of watering,}
    \item{medium}{factor indicating the growing medium.}
  }
}

\details{
The effect of three different factors - growing medium, watering and light - on
the quantity of homegrown mustard plants were investigated in the course
PAS 363 "Practical \& Applied Statistics" at the University of Sheffield. The
outcome is measured by the weight of the plants after ten days of growing. In
each of the 108 containers 50 seeds were planted in four different growing
media - soil, cotton wool, nespaper and sawdust - they were watered once, three
and five times respectively and exposed to normal, red or green light (by
covering the containers with colored cellophane film).

There are three missing values, because the seeds basically fell through the
newspaper in the respective containers, so that no plants grew. This
discourages the use of newspaper as growing medium for mustard.}

\references{
A. Zeileis (1998), "Influence of Growing Medium, Watering and Light on Weight
of Mustard Plants," Project Report, University of Sheffield.
}

\source{Achim Zeileis, Course PAS 363 "Practical \& Applied Statistics",
University of Sheffield}

\examples{
data(Mustard)
attach(Mustard)
summary(Mustard)

## main effects
boxplot(weight ~ medium)
boxplot(weight ~ watering)
boxplot(weight ~ light)

## pairwise interactions
interaction.plot(medium, light, weight, fun = function(x)
                 mean(x, na.rm = TRUE), ylab = "mean weight")
interaction.plot(watering, light, weight, fun = function(x)
                 mean(x, na.rm = TRUE), ylab = "mean weight")
interaction.plot(watering, medium, weight, fun = function(x)
                 mean(x, na.rm = TRUE), ylab = "mean weight")

fm1 <- lm(weight ~ (medium + watering + light)^2)
drop1(fm1)
fm2 <- step(fm1)
summary(fm2)
}

\keyword{datasets}
