\name{Simpson}
\alias{Simpson}
\non_function{}
\title{Simpson's Paradox}
\description{
Artificial data set for illustrating Simpson's paradox.
}

\usage{data(Simpson)}
\format{A data frame with 800 observations and 3 variables.
  \describe{
    \item{outcome}{Outcome of the study (failure, success),}
    \item{treatment}{Treatment or placebo,}
    \item{centre}{Indicates whether the observation is from \code{"clinic1"}
    or \code{"clinic2"}.}
  }
}

\details{
Suppose a study for assessing the success probability of a treatment is carried
out in two different clinic centres. Although the placebo seems to perform
better in both centres (but not significantly so at 5%), the treatment performs
better in the combined study (highly significant), because the influence of the
centre was neglected. This is called Simpson's paradox.
}

\examples{
data(Simpson)
attach(Simpson)
tab1 <- xtabs(~ treatment + outcome, subset = centre=="clinic1", data = Simpson)
tab2 <- xtabs(~ treatment + outcome, subset = centre=="clinic2", data = Simpson)
tab.all <- tab1 + tab2

## Clinic 1: Placebo better?
fisher.test(tab1)
## Clinic 2: Placebo better?
fisher.test(tab2)
## Both: Treatment better?? No, Simpson's paradox!
fisher.test(tab.all)
## Better:
mantelhaen.test(outcome, treatment, centre)
## or:
fm <- glm(outcome ~ centre * treatment, data = Simpson, family = binomial)
anova(fm, test = "F")
}

\keyword{datasets}
